import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import I18n
import Sco

import "./widgets"

Pane {
    id: root
    height: 134
    padding: 40
    topPadding: 30

    property color backgroundColor
    property alias appLogo: appLogo

    signal logo

    RowLayout {
        anchors.fill: parent
        spacing: 20

        ActionButton {
            id: appLogo
            Style.class: "logo"

            contentItem: SvgImage { source: Style.parameter("icon.topPanel.logo") }
            background: null

            onClicked: () => root.logo()

            Layout.preferredWidth: 103
            Layout.preferredHeight: 74
        }

        Space { width: 1 }

        ActionButton {
            id: lockButton
            Style.class: "lock"

            leftPadding: 30
            rightPadding: 30
            topPadding: 20
            bottomPadding: 20

            visible: Sco.showLock

            Layout.preferredWidth: 94
            Layout.preferredHeight: 74

            contentItem: SvgImage { source: Style.parameter("icon.topPanel.lock") }

            action: "AUTH_LOCK"
        }

        Space {
            Layout.fillWidth: true
        }

        Label {
            id: dateTimeLabel
            Style.class: "mainWindowDateTime"

            text: ""
            Timer {
                id: dateTimeTimer
                interval: 1000
                repeat: true
                running: true
                triggeredOnStart: true
                onTriggered: () => dateTimeLabel.text = new Date().toLocaleString("dd.MM.yyyy hh:mm")
            }
        }

        Label {
            Style.class: "mainWindowCashCode"
            visible: Sco.cashCode.length !== 0
            Tr {
                code: "mainWindowCashCode"
                args: [Sco.cashCode]
            }
        }

        ActionButton {
            id: help
            Style.class: "help"
            visible: Sco.showHelp
            icon: Style.parameter("icon.topPanel.help")
            iconSize: 32
            Tr { code: "mainWindowHelp" }

            action: "SCO_HELP"
            leftPadding: 30
            rightPadding: 30
            Layout.preferredHeight: 74
        }

        LanguageModel { id: langs }

        LanguageCombobox {
            model: langs
            visible: Sco.customerMode && langs.count > 1
            backgroundColor: root.backgroundColor
            Layout.preferredWidth: 194
            Layout.preferredHeight: 74
        }

        Control {
            padding: 20
            visible: Sco.showAttendPanel

            contentItem: Row {
                spacing: 10

                SvgImage {
                    source: Style.parameter("icon.topPanel.attendantMode")
                    width: 32
                    height: 32
                }

                Label {
                    Style.class: "mainWindowAttendantMode"
                    Tr { code: "mainWindowAttendantMode" }
                }
            }

            background: StrokedBorder {
                radius: 16
                strokeColor: Style.color("grayBorder")
                strokeWidth: 2
                dashPattern: [3, 4]
            }

            Layout.preferredHeight: 74
        }
    }

    background: Rectangle { color: root.backgroundColor }
}
