import QtQuick
import QtMultimedia

import Ad
import Core

import "../core"

BaseForm {
    padding: 0

    Context.context {
        inputSources: InputSources.All
        fullScreen: true
    }

    property var adItem: Ad.currentItem
    property bool displayed: Ad.displayed
    onDisplayedChanged: if (!displayed) nextTimer.stop()
    onAdItemChanged: if (adItem.time !== 0) nextTimer.start()

    MediaPlayer {
        id: player
        source: !ImageData.isImage(adItem.url) ? adItem.url : ""
        loops: MediaPlayer.Infinite
        onPlayingChanged: if (!player.playing && adItem.time === 0) PluginManager.internalAsync("AD_NEXT")
        onErrorOccurred: Ad.currentItemError()
        videoOutput: videoOutput
        onSourceChanged: play()

        Component.onCompleted: play()
    }

    VideoOutput {
        id: videoOutput
        anchors.fill: parent
        visible: !ImageData.isImage(adItem.url)
    }

    AnimatedImage {
        anchors.fill: parent
        visible: ImageData.isImage(adItem.url)
        source: ImageData.isImage(adItem.url) ? adItem.url : ""
        fillMode: Image.PreserveAspectFit
        onStatusChanged: {
            switch (status) {
            case AnimatedImage.Ready:
                playing = true
                break
            case AnimatedImage.Error:
                Ad.currentItemError()
            }
        }
    }

    MouseArea {
        anchors.fill: parent
        onClicked: if (!Ad.secondScreen) PluginManager.internalAsync("AD_STOP")
    }

    Timer {
        id: nextTimer
        interval: adItem.time * 1000
        onTriggered: PluginManager.internalAsync("AD_NEXT")
    }
}
