import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Check
import Core
import I18n
import PickList as PL

import "../core"
import "../picklist"
import "../widgets"

BaseForm {
    id: root
    Style.class: "formingForm"

    Context.context {
        inputSources: InputSources.All
        logoActionInfo: true
    }

    onVisibleChanged: modalPickList.close()

    focusPolicy: Qt.ClickFocus

    CheckModel { id: checkModel }
    FilterModel {
        id: positions
        sourceModel: checkModel
        filterFunction: (pos) => pos.type == CheckTypes.ItemType.Position
    }
    FilterModel {
        id: cards
        sourceModel: checkModel
        filterFunction: (pos) => pos.type == CheckTypes.ItemType.Card

        onLayoutChanged: () => cardItem.updateCard()
    }

    // TODO: вытащить в отдельную форму. Запускать через переход в контекст
    Dialog {
        id: modalPickList
        parent: Overlay.overlay
        anchors.centerIn: parent
        modal: true

        width: parent.width - leftMargin - rightMargin
        height: parent.height - topMargin - bottomMargin

        background: null
        opacity: opened ? 1 : 0
        margins: 30
        topMargin: 75
        bottomMargin: 80

        Overlay.modal: Rectangle {
            color: Style.color("modalBackground")
            opacity: modalPickList.opacity

            Behavior on opacity { NumberAnimation { duration: Style.animationDuration("forming.pickList", 250) } }
        }

        enter: Transition {
            NumberAnimation {
                property: "opacity"; from: 0; to: 1;
                duration: Style.animationDuration("forming.pickList", 250)
            }
        }

        exit: Transition {
            NumberAnimation {
                property: "opacity"; from: 1; to: 0;
                duration: Style.animationDuration("forming.pickList", 250)
            }
        }

        Control {
            anchors.fill: parent

            focusPolicy: Qt.ClickFocus

            contentItem: ColumnLayout {
                spacing: 36

                GroupBox {
                    contentItem: PickList {
                        grid: Qt.size(4, 6)

                        Action {
                            id: action
                            command: "PICKLIST_SELECT"
                            property var item

                            onSuccess: () => modalPickList.accept()
                        }

                        onSelected: (index) => {
                            action.item = PL.PickList.pageModel.modelItem(index)
                            action.exec()
                        }
                    }

                    Layout.fillWidth: true
                    Layout.fillHeight: true
                }

                ActionButton {
                    id: closeModalPickList
                    Style.class: "flat"
                    icon: Style.parameter("icon.pickList.close")
                    Tr { code: "pickListClose" }

                    onClicked: () => modalPickList.reject()

                    Layout.fillWidth: true
                    Layout.preferredHeight: 110
                }
            }
        }
    }

    ColumnLayout {
        anchors.fill: parent
        spacing: 20

        RowLayout {
            Layout.fillWidth: true

            ActionButton {
                id: inputCardButton
                action: "CHECK_INPUTCARD"

                ColumnLayout {
                    id: addButton
                    opacity: inputCardButton.contentItem == this
                    visible: inputCardButton.contentItem == this

                    Label {
                        color: inputCardButton.color
                        font: inputCardButton.font
                        Tr { code: "formingScanLoyaltyCard" }
                        Layout.alignment: Qt.AlignHCenter
                    }

                    Behavior on opacity {
                        OpacityAnimator { duration: Style.animationDuration("transition.forming.cardInput", 500) }
                    }
                }

                GridLayout {
                    // TODO: Устанавливать занчение в зависимости от наличия встроенной рекламы
                    property bool vertical: false
                    flow: vertical ? GridLayout.TopToBottom : GridLayout.LeftToRight
                    id: cardItem
                    opacity: inputCardButton.contentItem == this
                    visible: inputCardButton.contentItem == this
                    property var cardIndex: cards.index(0, 0)
                    property string cardName: cardIndex && cardIndex.valid ? cards.data(cardIndex, CheckModel.Name) : ""
                    property string cardBalance: cardIndex && cardIndex.valid ? cards.data(cardIndex, CheckModel.Balance).str : ""

                    function updateCard() {
                        this.cardIndex = cards.index(0, 0)
                    }

                    Row {
                        spacing: 20

                        Label {
                            color: inputCardButton.color
                            font: inputCardButton.font
                            text: cardItem.cardName
                        }

                        Control {
                            visible: cards.count > 1
                            leftPadding: 8
                            rightPadding: 8
                            contentItem: Label {
                                color: inputCardButton.background.color
                                font: inputCardButton.font
                                text: "+" + (cards.count - 1)
                            }

                            background: Rectangle {
                                color: inputCardButton.color
                                radius: height / 2
                            }
                        }

                        Layout.leftMargin: 30
                        Layout.topMargin: 20
                        Layout.bottomMargin: parent.vertical ? 0 : 20
                    }

                    Label {
                        color: inputCardButton.color
                        font: inputCardButton.font
                        Tr { code: "formingCardBalance"; args: [ cardItem.cardBalance ] }

                        Layout.alignment: parent.vertical ? Qt.AlignLeft : Qt.AlignRight
                        Layout.leftMargin: 30
                        Layout.topMargin: parent.vertical ? 10 : 20
                        Layout.rightMargin: 30
                        Layout.bottomMargin: 20
                    }

                    Behavior on opacity {
                        OpacityAnimator { duration: Style.animationDuration("transition.forming.cardInput", 500) }
                    }

                    Component.onCompleted: () => updateCard()
                }

                contentItem: cards.count === 0 ? addButton : cardItem

                Layout.fillWidth: true
                Layout.minimumHeight: 80

                Behavior on height {
                    NumberAnimation { duration: Style.animationDuration("transition.forming.cardInput", 100) }
                }
            }
        }

        GroupBox {
            id: pcBox
            padding: 30

            property bool showPickList: positions.count === 0

            contentItem: PickList {
                searchItem: GroupBox {
                    Style.class: "pickListSearch"

                    ActionButton {
                        anchors.fill: parent
                        Style.class: "pickListSearch"
                        icon: Style.parameter("icon.pickList.search")
                        Tr { code: "pickListSearchHint" }

                        onClicked: () => modalPickList.open()
                    }
                }

                onSelected: (index) => {
                    root.async("PICKLIST_SELECT", {
                        item: PL.PickList.pageModel.modelItem(index)
                    })
                }
            }

            Behavior on Layout.preferredHeight {
                NumberAnimation { easing.type: Easing.InOutQuad; duration: Style.animationDuration("transition.forming.pickList", 500) }
            }

            MouseArea {
                anchors.fill: parent
                enabled: !parent.showPickList

                onClicked: () => modalPickList.open()
            }

            Layout.fillWidth: true
            Layout.preferredHeight: showPickList ? 650 : 90
        }

        GroupBox {
            id: mainBox
            leftPadding: 30
            rightPadding: leftPadding
            topPadding: 30
            bottomPadding: 0

            contentItem: Item {
                Control {
                    anchors.fill: parent
                    topPadding: 60
                    bottomPadding: 90
                    visible: positions.count === 0
                    contentItem: ColumnLayout {
                        spacing: 40

                        SvgImage {
                            source: Style.parameter("icon.forming.emptyBasket")
                            Layout.preferredWidth: 250
                            Layout.preferredHeight: 250
                            Layout.alignment: Qt.AlignHCenter
                        }

                        Label {
                            Style.class: "formingEmptyBasketTitle"
                            Tr { code: "formingEmptyBasketTitle" }
                            horizontalAlignment: Qt.AlignHCenter
                            Layout.alignment: Qt.AlignHCenter
                        }

                        Label {
                            Style.class: "formingEmptyBasketDetails"
                            Tr { code: "formingEmptyBasketDetails" }
                            horizontalAlignment: Qt.AlignHCenter
                            Layout.alignment: Qt.AlignHCenter
                        }
                    }
                }

                Item {
                    anchors.fill: parent
                    visible: positions.count > 0

                    ColumnLayout {
                        anchors.fill: parent
                        spacing: 30

                        Label {
                            Style.class: "formingBasket"
                            Tr { code: "formingBasket" }
                            Layout.preferredHeight: contentHeight
                            Layout.preferredWidth: contentWidth
                        }

                        PositionList {
                            model: positions
                            edit: true
                            backgroundColor: mainBox.background.color
                            Layout.fillHeight: true
                            Layout.fillWidth: true

                            Rectangle {
                                color: Style.color("graySoft")
                                height: 1
                                anchors.left: parent.left
                                anchors.right: parent.right
                                anchors.top: parent.top
                            }
                        }

                        ActionButton {
                            Style.class: "outlined"
                            Tr { code: "formingAddBag" }
                            icon: Style.parameter("icon.forming.addBag")
                            action: "CHECK_ADDBAG"

                            background: Rectangle {
                                color: "transparent"
                            }

                            Rectangle {
                                anchors.left: parent.left
                                anchors.right: parent.right
                                anchors.top: parent.top
                                color: Style.color("grayBorder")
                                height: 1
                            }

                            Layout.fillWidth: true
                            Layout.preferredHeight: 105
                        }
                    }
                }
            }

            Layout.fillWidth: true
            Layout.fillHeight: true
        }

        GroupBox {
            id: ageVerifyBox
            Style.class: "formingAgeVerify"
            topPadding: 20
            rightPadding: 40
            bottomPadding: 20
            leftPadding: 40

            opacity: Check.needAgeVerify && height === implicitHeight ? 1 : 0

            contentItem: RowLayout {
                spacing: 40

                GroupBox {
                    Style.class: "formingAgeVerifyLabel"
                    topPadding: 16
                    rightPadding: 10
                    bottomPadding: 16
                    leftPadding: 10

                    contentItem: Label {
                        Style.class: "formingAgeVerifyLabel"
                        text: "18+"
                    }

                    Layout.preferredWidth: implicitWidth
                    Layout.preferredHeight: implicitHeight
                }

                Label {
                    Style.class: "formingAgeVerifyDetails"
                    Tr { code: "formingAgeVerifyDetails" }
                    verticalAlignment: Qt.AlignVCenter
                    wrapMode: Label.WordWrap
                    lineHeight: 1.2

                    Layout.preferredHeight: contentHeight
                    Layout.fillWidth: true
                }
            }

            Behavior on opacity {
                NumberAnimation { easing.type: Easing.InOutQuad; duration: Style.animationDuration("transition.forming.ageVerify", 250) }
            }

            Behavior on Layout.preferredHeight {
                NumberAnimation { easing.type: Easing.InOutQuad; duration: Style.animationDuration("transition.forming.ageVerify", 250) }
            }

            Layout.fillWidth: true
            Layout.preferredHeight: Check.needAgeVerify || opacity > 0 ? implicitHeight : 0
        }

        RowLayout {
            spacing: 40

            Label {
                Style.class: "formingTotal"
                Tr { code: "formingTotal" }
                Layout.fillWidth: true
            }

            Money {
                Style.class: "formingTotalSumNoDisc"
                visible: Check.total !== Check.totalNoDisc
                discount: true
                money: Check.totalNoDisc
                color: Style.color("grayDark")
                backgroundColor: Style.color("background")
            }

            Money {
                Style.class: "formingTotalSum"
                money: Check.total
            }

            Layout.fillWidth: true
            Layout.preferredHeight: 60
            Layout.bottomMargin: 20
        }

        ActionButton {
            id: subtotalButton
            property bool back: Check.status === CheckTypes.Status.None
            Style.class: !back ? "formingSubtotal" : "formingBack"
            enabled: back || positions.count > 0
            icon: !back ? Style.parameter("icon.forming.subtotal") : Style.parameter("icon.forming.back")
            iconSize: 32
            Tr { code: !subtotalButton.back ? "formingSubtotal" : "formingBack" }
            action: !back ? "CHECK_SUBTOTAL" : "CHECK_BACKTOWELCOME"
            Layout.fillWidth: true
            Layout.preferredHeight: 110
        }

        RowLayout {
            spacing: 20

            ActionButton {
                Style.class: "flat"
                Tr { code: "formingChangeNextQuantity" }
                icon: Style.parameter("icon.forming.inputQuantity")
                action: "CHECK_CHANGENEXTQUANTITY"
                Layout.fillWidth: true
                Layout.fillHeight: true
            }

            ActionButton {
                Style.class: "flat"
                Tr { code: "formingInput" }
                icon: Style.parameter("icon.forming.input")
                action: "CHECK_MANUALINPUT"
                Layout.fillWidth: true
                Layout.fillHeight: true
            }

            Layout.fillWidth: true
            Layout.maximumHeight: 90
        }
    }

    pushEnter: Transition {
        SequentialAnimation {
            NumberAnimation {
                target: root; property: "opacity"
                from: 0; to: 0
                duration: Style.animationDuration("transition.forming", 300)
            }
            NumberAnimation {
                target: root; property: "opacity"
                from: 0; to: 1
                easing.type: Easing.InCubic
                duration: Style.animationDuration("transition.forming", 500)
            }
        }
    }

    popEnter: Transition {
        NumberAnimation { target: root; property: "opacity"; to: 1; duration: 0 }
    }
}
