import QtQuick
import Qt5Compat.GraphicalEffects

import Core

Item {
    id: root

    property alias footer: footer
    property real multiplier: 1
    property real originRadius: 800
    readonly property real radius: originRadius * multiplier
    property color color: Style.color("welcomeBackground")
    property color footerColor: Style.color("green")
    property url footerImage: Style.parameter("image.welcomeFooter")
    property alias shadow: shadow

    Rectangle {
        id: footer

        property alias image: image

        anchors.bottom: root.bottom
        anchors.left: root.left
        anchors.right: root.right
        z: 1

        height: 1086
        color: root.footerColor

        SvgImage {
            id: image
            anchors.bottom: parent.bottom
            width: 1048
            height: 1086
            x: (parent.width - width) / 2

            source: root.footerImage
        }
    }

    Rectangle {
        id: circle

        x: (root.width - width) / 2
        y: (root.height - 550 - Math.sqrt( (root.originRadius * root.originRadius) - ((root.width * root.width) / 4) ) - root.originRadius + 120) + (root.radius - root.originRadius)
        z: 3

        width: 1300
        height: root.radius * 2
        radius: root.radius

        color: root.color
    }

    DropShadow {
        id: shadow
        visible: Style.parameter("shadows") === "true"

        anchors.fill: circle
        z: 2

        cached: true
        source: circle
        color: Style.color("welcomeShadow")
        verticalOffset: 50
        radius: 200
        samples: 1 + radius * 2
    }

    Rectangle {
        id: main

        x: 0
        y: 0
        z: 4

        width: root.width
        height: circle.y + (circle.height / 2)

        color: root.color
    }
}
