import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Check
import Core
import I18n

import "../core"
import "../widgets"

BaseForm {
    id: root
    Style.class: "welcomeForm"

    Context.context {
        inputSources: InputSources.All
        topPanelColor: Style.color("welcomeBackground")
        logoActionInfo: true
    }

    ColumnLayout {
        anchors.fill: parent
        spacing: 0

        Space {
            height: 80
        }

        Label {
            Style.class: "welcomeTitle"
            Tr { code: "welcomeTitle" }
            Layout.alignment: Qt.AlignHCenter
        }

        Label {
            Style.class: "welcomeScanBarcode"
            Tr { code: "welcomeScanBarcode" }
            horizontalAlignment: Qt.AlignHCenter
            wrapMode: Text.WordWrap
            Layout.alignment: Qt.AlignHCenter
            Layout.preferredWidth: parent.width
        }

        Label {
            Style.class: "welcomeOrPressButton"
            Tr { code: "welcomeOrPressButton" }
            horizontalAlignment: Qt.AlignHCenter
            Layout.alignment: Qt.AlignHCenter
        }

        Space {
            height: 30
        }

        ActionButton {
            Style.class: "welcomeStart"
            Tr { code: "welcomeStart" }
            action: "CHECK_START"
            Layout.alignment: Qt.AlignHCenter
            Layout.preferredWidth: 480
            Layout.preferredHeight: 128
        }

        ActionButton {
            Style.class: "welcomePriceChecker"
            Tr { code: "welcomePriceChecker" }
            action: "PRICECHECKER_SHOW"
            Layout.alignment: Qt.AlignHCenter
            Layout.preferredWidth: 480
            Layout.preferredHeight: 128
        }

        Space {
            height: 20
        }

        Label {
            Style.class: "welcomePaymentListTitle"
            Tr { code: "welcomePayments" }
            horizontalAlignment: Qt.AlignHCenter
            Layout.alignment: Qt.AlignHCenter
        }

        Space {
            height: 30
        }

        Column {
            ListView {
                orientation: ListView.Horizontal
                spacing: 80
                width: model.count * 200 + ((model.count - 1) * spacing)
                height: 50

                model: PaymentMethodsModel { withDisabled: false }

                delegate: Component {
                    Row {
                        spacing: 20

                        Column {
                            SvgImage {
                                width: 50
                                height: 50
                                source: model.welcomeIcon
                            }
                        }

                        Column {
                            Label {
                                Style.class: "welcomePaymentName"
                                Tr { code: model.welcomeName }
                                width: 130
                                wrapMode: Text.WordWrap
                                horizontalAlignment: Qt.AlignLeft
                                verticalAlignment: Qt.AlignVCenter
                            }
                        }
                    }
                }
            }

            Layout.alignment: Qt.AlignHCenter
        }

        Space {
            height: 250
        }
    }

    property real bgMultiplier: 1

    background: WelcomeBackground { multiplier: root.bgMultiplier }

    pushExit: Transition {
        SequentialAnimation {
            NumberAnimation {
                target: root; property: "bgMultiplier"
                from: 1.0; to: 0.97
                easing.type: Easing.OutQuad
                duration: Style.animationDuration("transition.welcome", 200)
            }
            NumberAnimation {
                target: root; property: "bgMultiplier"
                from: 0.97; to: 2
                easing.type: Easing.InCubic
                duration: Style.animationDuration("transition.welcome", 600)
            }
            NumberAnimation {
                target: root; property: "opacity"
                from: 1; to: 0
                easing.type: Easing.OutCubic
                duration: Style.animationDuration("transition.welcome", 500)
            }
        }
    }

    popEnter: Transition {
        NumberAnimation { target: root; property: "bgMultiplier"; to: 1; duration: 0 }
        NumberAnimation { target: root; property:      "opacity"; to: 1; duration: 0 }
    }
}
