import QtQml.Base
import QtQuick
import QtQuick.Layouts

import Core
import I18n
import Dialog

import "../core"
import "../widgets"

BaseForm {
    id: root
    Style.class: "askToContinueForm"

    property var action: DialogState.actions[Context.id.value]

    function accept() {
        action.result = true
        removeContext()
    }

    function reject() {
        action.result = false
        removeContext()
    }

    Keys.onEnterPressed: () => root.accept()
    Keys.onReturnPressed: () => root.accept()
    Keys.onEscapePressed: () => root.reject()

    contentItem: ColumnLayout {
        spacing: 40

        GroupBox {
            contentItem: ColumnLayout {

                ColumnLayout {
                    Layout.topMargin: 280
                    Layout.alignment: Qt.AlignTop
                    Layout.fillWidth: true

                    spacing: 40

                    Label {
                        id: title
                        Style.class: "askToContinueTitle"
                        horizontalAlignment: Label.AlignHCenter
                        wrapMode: Label.WordWrap
                        Tr { tr: action.title }

                        Layout.fillWidth: true
                    }

                    Label {
                        id: message
                        Style.class: "askToContinueMessage"
                        horizontalAlignment: Label.AlignHCenter
                        wrapMode: Label.WordWrap
                        Tr { tr: action.message }

                        Layout.fillWidth: true
                    }
                }
            }

            ColumnLayout {
                anchors.fill: parent

                SvgImage {
                    Layout.alignment: Qt.AlignVCenter | Qt.AlignHCenter

                    source: action.image
                }
            }

            Layout.fillWidth: true
            Layout.fillHeight: true
        }

        RowLayout {
            spacing: 40

            ActionButton {
                Style.class: "askToContinueCancel"
                Tr { tr: action.cancelButton }

                implicitWidth: 1

                onClicked: () => root.reject()

                Layout.fillWidth: true
                Layout.preferredHeight: 110
            }

            ActionButton {
                Style.class: "askToContinueApply"
                Tr { tr: action.okButton }

                implicitWidth: 1

                onClicked: () => root.accept()

                Layout.fillWidth: true
                Layout.preferredHeight: 110
            }
        }
    }
}
