import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import Dialog
import I18n

import "../widgets"
import "../core"

ModalForm {
    id: root
    Style.class: "choiceForm"

    property var action: DialogState.actions[Context.id.value]
    property bool hasImage: action.image.type !== ImageData.None

    function result(ok: bool) {
        action.result = ok
        removeContext()
    }

    Keys.onEnterPressed: () => result(true)
    Keys.onReturnPressed: () => result(true)
    Keys.onEscapePressed: () => result(false)

    ColumnLayout {
        id: layout
        anchors.left: parent.left
        anchors.right: parent.right
        Label {
            Layout.fillWidth: true
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Label.WordWrap
            Style.class: "choiceTitle"
            Tr { tr: action.title }
        }
        Space { height: 40 }
        Label {
            Layout.fillWidth: true
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Label.WordWrap
            Style.class: "choiceMessage"
            Tr { tr: action.message }
        }

        Space { height: 20; visible: hasImage }
        Item {
            height: action.imageHeight
            Layout.fillWidth: true
            visible: hasImage
            SvgImage {
                anchors.fill: parent
                source: action.image
            }
        }

        Space { height: 40 }
        GridLayout {
            Layout.fillWidth: true
            rowSpacing: 10
            columnSpacing: 20
            flow: action.flow
            Item {
                Layout.preferredHeight: 100
                Layout.fillWidth: true
                ActionButton {
                    anchors.fill: parent
                    Style.class: "choiceYesButton"
                    Tr { tr: action.okButton }
                    onClicked: () => root.result(true)
                }
            }
            Item {
                Layout.preferredHeight: 100
                Layout.fillWidth: true
                ActionButton {
                    anchors.fill: parent
                    Style.class: root.action.flow == GridLayout.LeftToRight ? "choiceNoButton"
                                                                     : "choiceNoBottomButton"
                    Tr { tr: action.cancelButton }
                    onClicked: () => root.result(false)
                }
            }
        }
    }
}
