import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import Dialog
import I18n

import "../widgets"
import "../core"

ModalForm {
    id: root
    Style.class: "inputQuantityForm"
    Context.inputSources: InputSources.Keyboard

    property Component simpleInfo: Label {
        Style.class: "inputQuantityMessage"
        Tr { tr: action.message }
        horizontalAlignment: Text.AlignHCenter
    }

    property Component extendedInfo: GoodsCard {
        name: action.name
        barcode: action.barcode
        image: action.image.exists ? action.image : Style.parameter("image.inputQuantity.placeholder")
        price: action.price

        labelName: "inputQuantityName"
        labelBarcode: "inputQuantityBarcode"
        moneyPrice: "inputQuantityPrice"
    }

    property var action: DialogState.actions[Context.id.value]
    property var minQuantity: parseStr(action.minQuantity.str)

    function parseStr(value) { return action.fractional ? parseFloat(value) : parseInt(value) }

    Keys.onEnterPressed: () => okButton.clicked()
    Keys.onReturnPressed: () => okButton.clicked()
    Keys.onEscapePressed: () => cancelButton.clicked()

    ColumnLayout {
        id: layout
        anchors.left: parent.left
        anchors.right: parent.right
        Label {
            id: title
            Layout.fillWidth: true
            wrapMode: Label.WordWrap
            Style.class: "inputQuantityTitle"
            Tr { tr: action.title }
            horizontalAlignment: Text.AlignHCenter
        }
        Space { height: 40 }
        Loader {
            Layout.fillWidth: true
            sourceComponent: action.extendedInfo ? extendedInfo : simpleInfo
        }
        Space { height: 20 }
        RowLayout {
            spacing: 10
            Item {
                Layout.fillWidth: true
                Layout.preferredHeight: 80
                ActionButton {
                    id: minus
                    anchors.fill: parent
                    enabled: !root.action.fractional
                    icon: enabled ? Style.parameter("icon.inputQuantity.minus")
                                  : Style.parameter("icon.inputQuantity.minus_disable")
                    onClicked: input.text = parseStr(input.text) - 1
                }
            }
            Item {
                Layout.fillWidth: true
                Layout.preferredHeight: 80
                GroupBox {
                    anchors.fill: parent
                    Style.class: "inputQuantityInputField"
                    FocusScope {
                        anchors.fill: parent
                        focus: true
                        TextEdit {
                            id: input
                            anchors.centerIn: parent
                            Style.class: "inputQuantityInputField"
                            text: Math.max(parseStr(action.quantity.str), minQuantity)
                            focus: true
                            IntValidator { id: iv; bottom: minQuantity }
                            DoubleValidator {
                                id: dv
                                bottom: minQuantity
                                decimals: 3
                            }
                            validator: action.fractional ? dv : iv
                            onTextChanged: () => {
                                let text = this.text.replace(/^0*/, "")
                                const isMin = (parseStr(text) > minQuantity)
                                minus.enabled = isMin && !root.action.fractional
                                okButton.enabled = isMin
                                if (text.length === 0 || text[0] === '.')
                                    text = "0" + text
                                if (this.text !== text)
                                    this.text = text
                            }
                            onFocusChanged: () => { if (focus) input.selectAll() }
                        }
                    }
                }
            }
            Item {
                Layout.fillWidth: true
                Layout.preferredHeight: 80
                ActionButton {
                    anchors.fill: parent
                    enabled: !root.action.fractional
                    icon: Style.parameter("icon.inputQuantity.plus")
                    onClicked: input.text = (input.text.length > 0 ? parseStr(input.text) : 0) + 1
                }
            }
        }
        Space { height: 20 }
        InlineKeyboard {
            Layout.preferredHeight: 350
            Layout.fillWidth: true
            layoutType: "digits"
        }
        Space { height: 20 }
        ActionButton {
            id: okButton
            Layout.preferredHeight: 110
            Layout.fillWidth: true
            Style.class: "inputOkButton"
            Tr { tr: action.okButton; fallback: "inputQuantityOk" }
            onClicked: () => {
                if (!enabled)
                    return
                if (input.text.length == 0) {
                    root.action.quantity = Quantity.zero
                } else if (root.action.fractional) {
                    root.action.quantity = Quantity.fromGrams(input.text * 1000)
                } else {
                    root.action.quantity = Quantity.fromCount(input.text)
                }
                root.action.inputCanceled = false
                removeContext()
            }
        }
        Space { height: 10; visible: action.showCancel }
        ActionButton {
            id: cancelButton
            Layout.preferredHeight: 110
            Layout.fillWidth: true
            visible: root.action.showCancel
            Style.class: "inputCancelButton"
            Tr { tr: action.cancelButton; fallback: "inputQuantityCancel" }
            icon: Style.parameter("icon.inputQuantity.cancel")
            onClicked: () => {
                root.action.quantity = Quantity.zero
                root.action.inputCanceled = true
                removeContext()
            }
        }
    }
}
