import QtQuick
import QtQuick.Layouts

import Core
import I18n
import Input

import "../core"
import "../widgets"

ModalForm {
    id: root

    property var action: Input.weighingAction

    Keys.onEnterPressed: () => okButton.clicked()
    Keys.onReturnPressed: () => okButton.clicked()
    Keys.onEscapePressed: () => cancelButton.clicked()

    ColumnLayout {
        anchors.fill: parent

        spacing: 40

        Label {
            id: title
            Style.class: "weightTitle"
            Tr { code: action.title.empty ? "weightTitle" : action.title }

            Layout.alignment: Qt.AlignHCenter
        }

        Label {
            id: message
            Style.class: "weightHint"
            Tr { code: "weightHint" }

            Layout.alignment: Qt.AlignHCenter
        }

        GoodsCard {
            name: action.name
            barcode: action.barcode
            image: action.image.valid ? action.image : "image.weight.placeholder"
            price: action.price

            labelName: "weightName"
            labelBarcode: "weightBarcode"
            moneyPrice: "weightPrice"
        }

        Label {
            id: weight
            Style.class: "weightState"
            Tr { code: "weightState"; args: [ Input.weight.str ] }

            Layout.alignment: Qt.AlignHCenter
        }

        ColumnLayout {
            spacing: 15

            Space { height: 60 - parent.spacing - parent.parent.spacing }

            ActionButton {
                id: okButton
                Style.class: "weightOk"
                visible: Input.confirmWeighing
                enabled: !Input.weight.zero
                Tr { code: "weightConfirm" }
                ActionButtonTimer {
                    id: timer
                    seconds: Input.confirmWeighingTimeout / 1000
                    icon: Style.parameter("icon.weight.timer")
                    label.color: "white"
                    onTimeout: () => okButton.clicked()
                }
                onEnabledChanged: () => {
                    if (enabled && visible)
                        timer.run()
                    else
                        timer.cancel()
                }

                onClicked: () => { if(enabled) root.removeContext() }

                Layout.fillWidth: true
                Layout.preferredHeight: 105
            }

            ActionButton {
                id: cancelButton
                Style.class: "weightCancel"
                Tr { code: "weightCancel" }
                icon: Style.parameter("icon.weight.cancel")
                onClicked: () => {
                    Input.weight = Fract.fromGrams(0)
                    root.removeContext()
                }

                Layout.fillWidth: true
                Layout.preferredHeight: 105
            }

            Layout.fillWidth: true
        }
    }
}
