import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import Check
import I18n
import WeightControl

import "../check"
import "../core"
import "../widgets"

BaseForm {
    id: root
    padding: 50
    topPadding: 5
    focusPolicy: Qt.ClickFocus

    Context.logoActionInfo: "WEIGHTCONTROL_ERRORAUTH"

    property int error: WeightControl.error

    GroupBox {
        anchors.fill: parent
        ColumnLayout {
            anchors.centerIn: parent
            Label {
                Layout.alignment: Qt.AlignHCenter
                horizontalAlignment: Text.AlignHCenter
                Style.class: "weightControlErrorTitle"
                Tr {
                    code: {
                        switch(root.error) {
                        case WeightControlTypes.NotAdded: return "wceNotAddedTitle"
                        case WeightControlTypes.NotScanned: return "wceNotScannedTitle"
                        case WeightControlTypes.Overweight: return "wceOverweightTitle"
                        case WeightControlTypes.Removed: return "wceRemovedTitle"
                        case WeightControlTypes.RemovedHeft: return "wceRemovedHeftTitle"
                        case WeightControlTypes.NotStable: return "wceNotStableTitle"
                        case WeightControlTypes.WrongWeight: return "wceWrongWeightTitle"
                        case WeightControlTypes.NotScannedAbuse: return "wceNotScannedAbuseTitle"
                        case WeightControlTypes.NotScannedPay: return "wceNotScannedPayTitle"
                        default: return ""
                        }
                    }
                }
            }
            Space { height: 50 }
            Label {
                Layout.alignment: Qt.AlignHCenter
                horizontalAlignment: Text.AlignHCenter
                Style.class: "weightControlErrorHint"
                Tr {
                    code: {
                        switch(root.error) {
                        case WeightControlTypes.NotAdded: return "wceNotAddedHint"
                        case WeightControlTypes.NotScanned: return "wceNotScannedHint"
                        case WeightControlTypes.Overweight: return "wceOverweightHint"
                        case WeightControlTypes.Removed: return "wceRemovedHint"
                        case WeightControlTypes.NotStable: return "wceNotStableHint"
                        case WeightControlTypes.WrongWeight: return "wceWrongWeightHint"
                        case WeightControlTypes.NotScannedAbuse: return "wceNotScannedAbuseHint"
                        case WeightControlTypes.NotScannedPay: return "wceNotScannedPayHint"
                        case WeightControlTypes.RemovedHeft: return "wceRemovedHeftHint"
                        default: return ""
                        }
                    }
                }
            }
            Space { height: 250 }
            Loader {
                Layout.alignment: Qt.AlignHCenter
                source: {
                    switch(root.error) {
                    case WeightControlTypes.NotStable: return "UnstableImage.qml"
                    case WeightControlTypes.WrongWeight: return "WrongWeightImage.qml"
                    case WeightControlTypes.Overweight:
                    case WeightControlTypes.NotScannedAbuse:
                    case WeightControlTypes.NotScannedPay:
                    case WeightControlTypes.NotScanned: return "RemovingImage.qml"
                    case WeightControlTypes.NotAdded:
                    case WeightControlTypes.Removed:
                    case WeightControlTypes.RemovedHeft: return "AddingImage.qml"
                    default: return ""
                    }
                }
            }
            Space { height: 50 }
            PositionList {
                id: positionList
                property real delegateHeight: 100
                Layout.alignment: Qt.AlignHCenter
                Layout.preferredWidth: 840
                Layout.preferredHeight: delegateHeight * Math.min(model.count, 5)
                                        + Math.min(model.count, 5) + 1 // Разделители
                visible: [ WeightControlTypes.WrongWeight, WeightControlTypes.NotAdded,
                    WeightControlTypes.NotScanned, WeightControlTypes.Removed,
                    WeightControlTypes.RemovedHeft ].indexOf(root.error) >= 0
                Component.onCompleted: () => scrollToEnd()
                CheckModel { id: checkModel }
                model: FilterModel {
                    id: model
                    sourceModel: checkModel
                    filterFunction: (pos) => pos.type == CheckTypes.ItemType.Position
                }
                delegate: ColumnLayout {
                    width: positionList.width
                    height: positionList.delegateHeight
                    DashLineSeparator {
                        Layout.fillWidth: true; Layout.alignment: Qt.AlignTop; visible: !index
                        dashPattern: [1, 0]; strokeWidth: 1; color: Style.color("graySoft")
                    }
                    RowLayout {
                        Layout.fillWidth: true; Layout.alignment: Qt.AlignVCenter
                        Space { width: 10 }
                        Label {
                            Layout.fillWidth: true
                            Style.class: "weightControlPositionName"
                            text: model.name
                            elide: Text.ElideRight
                        }
                        Space { width: 20 }
                        Label {
                            leftPadding: 17; rightPadding: 17; topPadding: 6; bottomPadding: 6
                            Style.class: "weightControlPositionError"
                            Tr { code: model.wcStatus }
                            visible: text.length > 0
                        }
                        Space { width: 20 }
                        Label {
                            leftPadding: 17; rightPadding: 17; topPadding: 6; bottomPadding: 6
                            Style.class: "weightControlPositionQuantity"
                            text: "x" + model.quantity.str
                        }
                        Space { width: 10 }
                    }
                    DashLineSeparator {
                        Layout.fillWidth: true; Layout.alignment: Qt.AlignBottom
                        dashPattern: [1, 0]; strokeWidth: 1; color: Style.color("graySoft")
                    }
                }
            }
        }
    }
}
