import QtQuick
import QtQuick.Shapes
import QtQuick.Layouts

import Core

/**
 * @brief Виджет отображения денег (цена или стоимость позиции)
 *
 * @param money деньги типа @p Core::Money
 * @param discount является ценой без скидки (будет зачеркнуто и раскрасится в красный цвет)
 */
Item {
    id: root

    Style.class: "price"

    property bool discount
    property var money
    property color backgroundColor
    property color color: discount ? Style.color("redSoft") : Style.color("black")
    property color styleColor: label.Style.text.color

    implicitWidth: label.contentWidth
    implicitHeight: label.contentHeight

    onMoneyChanged: () => label.updateText()
    Component.onCompleted: () => label.updateText()

    Label {
        id: label
        Style.class: root.Style.class
        color: root.color
        textFormat: Label.RichText
        verticalAlignment: Label.AlignBottom

        function updateText()  {
            if (!money) {
                this.text = "0.<small>00</small>"
                return
            }
            this.text = moneyToString(money.integral) + (money.decimals > 0 ? (".<small>" + fillZeros(money.fraction, money.decimals) + "</small>") : "")
        }

        // Строковое отображение денег с пробелами между тысячными и миллионными частями
        // Пример: 1000 -> "1 000"
        function moneyToString(money) {
            let o = ''
            let left = String(money)
            while (left.length > 0) {
                if (left.length % 3 === 0)
                    o += ' '
                o += left[0]
                left = left.substring(1)
            }
            return o
        }

        // Наполнить строку нулями до необходимой ширины
        function fillZeros(money, width) {
            let o = String(money)
            while (o.length < width)
                o = "0" + o
            return o
        }
    }

    Shape {
        anchors.fill: parent
        visible: root.discount

        ShapePath {
            strokeColor: root.backgroundColor
            strokeWidth: root.height * 0.10
            startX: 0
            startY: root.height * 0.85

            PathLine { x: root.width; y: root.height * 0.35 }
        }

        ShapePath {
            strokeColor: root.color
            strokeWidth: root.height * 0.08
            startX: 0
            startY: root.height * 0.80

            PathLine { x: root.width; y: root.height * 0.30 }
        }
    }
}
